@@ -35,7 +35,7 @@ class WebSocketInternalError(Exception):
 
 Scope = Mapping[str, Any]
 Message = Mapping[str, Any]
-Context = Optional[Mapping[str, Any]]
+Context = Mapping[str, Any]
 Info = Optional[MutableMapping[str, Any]]
 
 Receive = Callable[[], Awaitable[Message]]
@@ -122,8 +122,12 @@ WebSocketRequestCallback = Callable[
     [Scope, Info, RouteMatches, WebSocket],
     Awaitable[None]
 ]
+HttpChainedCallback = Callable[
+    [Scope, Info, RouteMatches, Content],
+    Awaitable[HttpFullResponse]
+]
 HttpMiddlewareCallback = Callable[
-    [Scope, Info, RouteMatches, Content, HttpRequestCallback],
+    [Scope, Info, RouteMatches, Content, HttpChainedCallback],
     Awaitable[HttpFullResponse]
 ]
 
